@@ -80,6 +80,8 @@ public:
     bool get(const K&, V&);
     bool set(const K&, const V&);
 
+    void preload();
+
     template <class T>
     void range(const K& key1, const K& key2, T& result);
 
@@ -232,7 +234,8 @@ private:
         time_t last_;
         bool dirty_;
 
-        _PageInfo(Page* page = 0) : page_(page), count_(0), last_(time(nullptr)), dirty_(false) {}
+        _PageInfo(Page* page = 0) :
+            page_(page), count_(0), last_(time(nullptr)), dirty_(false) {}
     };
 
     typedef std::map<unsigned long, _PageInfo> Cache;
