@@ -89,13 +89,11 @@ public:  // methods
     std::string asRawString() const;
 
     bool operator!=(const URI& other) const {
-        return scheme_ != other.scheme_ || name_ != other.name_ || user_ != other.user_ || host_ != other.host_ ||
-               port_ != other.port_ || queryValues_ != other.queryValues_ || fragment_ != other.fragment_;
+        return scheme_ != other.scheme_ || name_ != other.name_ || user_ != other.user_ || host_ != other.host_ || port_ != other.port_ || queryValues_ != other.queryValues_ || fragment_ != other.fragment_;
     }
 
     bool operator==(const URI& other) const {
-        return scheme_ == other.scheme_ && name_ == other.name_ && user_ == other.user_ && host_ == other.host_ &&
-               port_ == other.port_ && queryValues_ == other.queryValues_ && fragment_ == other.fragment_;
+        return scheme_ == other.scheme_ && name_ == other.name_ && user_ == other.user_ && host_ == other.host_ && port_ == other.port_ && queryValues_ == other.queryValues_ && fragment_ == other.fragment_;
     }
 
 protected:  // methods
@@ -107,6 +105,9 @@ private:  // methods
     void parse(const std::string& uri, size_t first, bool authority, bool query, bool fragment);
     void parseQueryValues(const std::string& query);
 
+    static std::string encode(const std::string &value);
+    static std::string decode(const std::string &value);
+
 private:  // members
     std::string name_;
     std::string scheme_;
