@@ -19,8 +19,7 @@
 
 //----------------------------------------------------------------------------------------------------------------------
 
-namespace eckit {
-namespace geometry {
+namespace eckit::geometry {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -134,5 +133,4 @@ bool GreatCircle::crossesPoles() const {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace geometry
-}  // namespace eckit
+}  // namespace eckit::geometry
