@@ -8,72 +8,63 @@
  * does it submit to any jurisdiction.
  */
 
-// File Select.h
-// Baudouin Raoult - ECMWF Mar 97
+/// @author Baudouin Raoult
+/// @date Mar 97
 
 #ifndef eckit_Select_h
 #define eckit_Select_h
 
-#if 0
-#ifdef __hpux
-#include <sys/time.h>
-#else
-#include <sys/select.h>
-#endif
-#endif
 
 #include <sys/select.h>
 
 #include "eckit/memory/NonCopyable.h"
 
-//-----------------------------------------------------------------------------
 
 namespace eckit {
 
 //-----------------------------------------------------------------------------
 
+namespace net {
 class TCPSocket;
+};
 
 /// Wraps calls to select
 class Select : private NonCopyable {
 
 public:
+    // -- Contructors
 
-// -- Contructors
+    Select();
+    explicit Select(int);
+    explicit Select(net::TCPSocket&);
 
-	Select();
-	Select(int);
-	Select(TCPSocket&);
+    // -- Destructor
 
-// -- Destructor
+    ~Select();
 
-	~Select();
+    // -- Methods
 
-// -- Methods
+    bool ready(long sec = 20);
 
-	bool ready(long sec = 20);
+    void add(net::TCPSocket&);
+    void add(int);
 
-	void add(TCPSocket&);
-	void add(int);
+    void remove(net::TCPSocket&);
+    void remove(int);
 
-	void remove(TCPSocket&);
-	void remove(int);
-
-	bool set(TCPSocket&);
-	bool set(int);
+    bool set(net::TCPSocket&);
+    bool set(int);
 
 private:
+    // -- Members
 
-// -- Members
-
-	fd_set files_;
-	fd_set set_;
-	int    last_;
-
+    fd_set files_;
+    fd_set set_;
+    int last_;
 };
 
 //-----------------------------------------------------------------------------
 
-} // namespace eckit
+}  // namespace eckit
 
 #endif
