@@ -20,8 +20,9 @@ StdPipe::StdPipe(const std::string& name, const std::string& mode) :
     file_(0) {
     file_ = ::popen(name.c_str(), mode.c_str());
 
-    if (file_ == 0)
+    if (file_ == 0) {
         throw CantOpenFile(name);
+    }
 }
 
 StdPipe::~StdPipe() {
