@@ -27,8 +27,8 @@ public:  // methods
     StatusTarget();
 
 private:
-    virtual void line(const char* line) override;
-    virtual void print(std::ostream& s) const override;
+    void line(const char* line) override;
+    void print(std::ostream& s) const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
