@@ -20,13 +20,15 @@ namespace eckit {
 
 const char* TimeStamp::defaultFormat_ = "%Y-%m-%d %H:%M:%S";
 
-TimeStamp::TimeStamp(const std::string& format) : time_(Clock::now()), format_(format) {}
+TimeStamp::TimeStamp(const std::string& format) :
+    time_(Clock::now()), format_(format) {}
 
-TimeStamp::TimeStamp(time_t t, const std::string& format) : time_(t), format_(format) {}
+TimeStamp::TimeStamp(time_t t, const std::string& format) :
+    time_(t), format_(format) {}
 
 std::ostream& operator<<(std::ostream& s, const TimeStamp& x) {
     char buf[80];
-#ifdef eckit_HAVE_GMTIME_R
+#if eckit_HAVE_GMTIME_R
     struct tm t;
     ::strftime(buf, sizeof(buf), x.format_.c_str(), gmtime_r(&x.time_, &t));
 #else
