@@ -37,9 +37,7 @@
 #include "eckit/thread/AutoLock.h"
 #include "eckit/thread/StaticMutex.h"
 
-namespace eckit {
-namespace net {
-
+namespace eckit::net {
 
 static in_addr none = {INADDR_NONE};
 
@@ -116,8 +114,9 @@ void TCPSocket::closeInput() {
 long TCPSocket::write(const void* buf, long length) {
 
     // Allow zero length packets
-    if (length == 0)
+    if (length == 0) {
         return ::write(socket_, buf, length);
+    }
 
     long requested = length;
 
@@ -203,8 +202,9 @@ long TCPSocket::write(const void* buf, long length) {
 }
 
 long TCPSocket::read(void* buf, long length) {
-    if (length <= 0)
+    if (length <= 0) {
         return length;
+    }
 
     static bool useSelectOnTCPSocket = Resource<bool>("useSelectOnTCPSocket", false);
     long received                    = 0;
@@ -248,8 +248,9 @@ long TCPSocket::read(void* buf, long length) {
                 Log::status() << "Resuming transfer" << std::endl;
                 len = ::read(socket_, p, length);
             }
-            else
+            else {
                 len = ::read(socket_, p, length);
+            }
         }
         else {
             len = ::read(socket_, p, length);
@@ -420,8 +421,9 @@ TCPSocket& TCPClient::connect(const std::string& remote, int port, int retries,
             switch (errno) {
                 case ECONNREFUSED:
                     if (++tries >= retries) {
-                        if (retries >= 0)
+                        if (retries >= 0) {
                             throw TooManyRetries(tries);
+                        }
                     }
                     ::sleep(5);
                     break;
@@ -481,33 +483,38 @@ TCPSocket& TCPClient::connect(const std::string& remote, int port, int retries,
     return *this;
 }
 
-void set_socket_buffer_size(int& socket, const char* ssock, const int& stype, const int size ) {
+void set_socket_buffer_size(int& socket, const char* ssock, const int& stype, const int size) {
     Log::debug() << "Setting " << ssock << " buffer size " << size << std::endl;
 
     int flg           = 0;
     socklen_t flgsize = sizeof(flg);
 
-    if (getsockopt(socket, SOL_SOCKET, stype, &flg, &flgsize) < 0)
-            Log::warning() << "getsockopt " << ssock << " " << Log::syserr << std::endl;
+    if (getsockopt(socket, SOL_SOCKET, stype, &flg, &flgsize) < 0) {
+        Log::warning() << "getsockopt " << ssock << " " << Log::syserr << std::endl;
+    }
 
-   if (flg != size) {
-        if (setsockopt(socket, SOL_SOCKET, stype, &size, sizeof(size)) < 0)
+    if (flg != size) {
+        if (setsockopt(socket, SOL_SOCKET, stype, &size, sizeof(size)) < 0) {
             Log::warning() << "setsockopt " << ssock << " " << Log::syserr << std::endl;
+        }
 
-        if (getsockopt(socket, SOL_SOCKET, stype, &flg, &flgsize) < 0)
+        if (getsockopt(socket, SOL_SOCKET, stype, &flg, &flgsize) < 0) {
             Log::warning() << "getsockopt " << ssock << " " << Log::syserr << std::endl;
+        }
 
         bool warn = (flg != size);
 #if defined(__linux__)
         // For Linux we ignore if the effective size is 2x what is set
         // see Linux 'man 7 socket'
-        // when set using setsockopt() the Linux kernel doubles the socket buffer size 
+        // when set using setsockopt() the Linux kernel doubles the socket buffer size
         // to allow space for bookkeeping overhead and  this  doubled  value  is
         // returned  by  getsockopt(). The minimum (doubled) value for this option is 2048.
-        warn &= !(flg == 2 * size);  
+        warn &= !(flg == 2 * size);
 #endif
-        if(warn)
-            Log::warning() << "Attempt to set " << stype << " buffer size to " << size << " but kernel set size to " << flg << std::endl;
+        if (warn) {
+            Log::warning() << "Attempt to set " << stype << " buffer size to " << size
+                           << " but kernel set size to " << flg << std::endl;
+        }
     }
 }
 
@@ -524,14 +531,16 @@ int TCPSocket::createSocket(int port, const SocketOptions& opts) {
 
     if (opts.reuseAddr()) {
         int flg = 1;
-        if (::setsockopt(s, SOL_SOCKET, SO_REUSEADDR, &flg, sizeof(flg)) < 0)
+        if (::setsockopt(s, SOL_SOCKET, SO_REUSEADDR, &flg, sizeof(flg)) < 0) {
             Log::warning() << "setsockopt SO_REUSEADDR" << Log::syserr << std::endl;
+        }
     }
 
     if (opts.keepAlive()) {
         int flg = 1;
-        if (::setsockopt(s, SOL_SOCKET, SO_KEEPALIVE, &flg, sizeof(flg)) < 0)
+        if (::setsockopt(s, SOL_SOCKET, SO_KEEPALIVE, &flg, sizeof(flg)) < 0) {
             Log::warning() << "setsockopt SO_KEEPALIVE" << Log::syserr << std::endl;
+        }
     }
 
     if (opts.reusePort()) {
@@ -546,8 +555,9 @@ int TCPSocket::createSocket(int port, const SocketOptions& opts) {
         linger ling;
         ling.l_onoff  = 0;
         ling.l_linger = 0;
-        if (::setsockopt(s, SOL_SOCKET, SO_LINGER, &ling, sizeof(ling)) < 0)
+        if (::setsockopt(s, SOL_SOCKET, SO_LINGER, &ling, sizeof(ling)) < 0) {
             Log::warning() << "setsockopt SO_LINGER" << Log::syserr << std::endl;
+        }
 #endif
 
 #ifdef SO_DONTLINGER
@@ -558,14 +568,16 @@ int TCPSocket::createSocket(int port, const SocketOptions& opts) {
 
     if (opts.ipLowDelay()) {
         int tos = IPTOS_LOWDELAY;
-        if (::setsockopt(s, IPPROTO_IP, IP_TOS, &tos, sizeof(tos)) < 0)
+        if (::setsockopt(s, IPPROTO_IP, IP_TOS, &tos, sizeof(tos)) < 0) {
             Log::warning() << "setsockopt IP_TOS" << Log::syserr << std::endl;
+        }
     }
 
     if (opts.tcpNoDelay()) {
         int flag = 1;
-        if (::setsockopt(s, IPPROTO_TCP, TCP_NODELAY, (char*)&flag, sizeof(flag)) < 0)
+        if (::setsockopt(s, IPPROTO_TCP, TCP_NODELAY, (char*)&flag, sizeof(flag)) < 0) {
             Log::warning() << "setsockopt TCP_NODELAY" << Log::syserr << std::endl;
+        }
     }
 
     receiveBufferSize_ = receiveBufferSize_ ? receiveBufferSize_ : opts.receiveBufferSize();
@@ -585,10 +597,12 @@ int TCPSocket::createSocket(int port, const SocketOptions& opts) {
 
     std::string addr = bindingAddress();
 
-    if (addr.length() == 0)
+    if (addr.length() == 0) {
         sin.sin_addr.s_addr = INADDR_ANY;
-    else
+    }
+    else {
         sin.sin_addr.s_addr = ::inet_addr(addr.c_str());
+    }
 
     while (::bind(s, reinterpret_cast<sockaddr*>(&sin), sizeof(sin)) == -1) {
         Log::warning() << "bind port " << localPort_ << " " << addr << Log::syserr << std::endl;
@@ -648,8 +662,9 @@ std::string TCPSocket::addrToHost(in_addr addr) {
 
     std::map<uint32_t, std::string>::iterator j = cache.find(addr.s_addr);
 
-    if (j != cache.end())
+    if (j != cache.end()) {
         return (*j).second;
+    }
 
     hostent* h;
 
@@ -669,7 +684,7 @@ std::string TCPSocket::addrToHost(in_addr addr) {
     else
         h = &host;
 #else
-    h = gethostbyaddr(reinterpret_cast<char*>(&addr), sizeof(addr), AF_INET);
+    h             = gethostbyaddr(reinterpret_cast<char*>(&addr), sizeof(addr), AF_INET);
 #endif
 
     std::string s      = h ? std::string(h->h_name) : IPAddress(addr).asString();
@@ -681,10 +696,10 @@ std::string TCPSocket::addrToHost(in_addr addr) {
 std::string TCPSocket::hostName(const std::string& h, bool full) {
     in_addr_t addr = ::inet_addr(h.c_str());
     if (addr == (in_addr_t)-1) {
-        if (full)
+        if (full) {
             return h;
-        else
-            return h.substr(0, h.find('.'));
+        }
+        return h.substr(0, h.find('.'));
     }
 
     struct in_addr a;
@@ -705,7 +720,7 @@ void TCPSocket::register_ignore_sigpipe() {
     struct sigaction act;
     eckit::zero(act);
     act.sa_handler = SIG_IGN;
-    act.sa_flags = SA_RESTART;
+    act.sa_flags   = SA_RESTART;
     SYSCALL(::sigaction(SIGPIPE, &act, nullptr));  //< shouldn't fail -- see ERROR conditions in man(2) sigaction
 #endif
 }
@@ -750,8 +765,9 @@ long TCPSocket::rawRead(void* buf, long length) {
 }
 
 bool TCPSocket::stillConnected() const {
-    if (socket_ == -1)
+    if (socket_ == -1) {
         return false;
+    }
 
     fd_set r;
     fd_set e;
@@ -767,8 +783,9 @@ bool TCPSocket::stillConnected() const {
     ::timeval tv = {0, 0};
 
     if (::select(socket_ + 1, &r, &w, &e, &tv) >= 0) {
-        if (!FD_ISSET(socket_, &r))
+        if (!FD_ISSET(socket_, &r)) {
             return true;
+        }
 
         int n = 0;
         if (::ioctl(socket_, FIONREAD, &n) < 0) {
@@ -783,10 +800,8 @@ bool TCPSocket::stillConnected() const {
 
         return true;
     }
-    else {
-        Log::info() << "TCPSocket::stillConnected(select) failed " << Log::syserr << std::endl;
-        return false;
-    }
+    Log::info() << "TCPSocket::stillConnected(select) failed " << Log::syserr << std::endl;
+    return false;
 }
 
 void TCPSocket::debug(bool on) {
@@ -813,6 +828,4 @@ std::ostream& operator<<(std::ostream& s, in_addr a) {
     return s;
 }
 
-
-}  // namespace net
-}  // namespace eckit
+}  // namespace eckit::net
