@@ -10,19 +10,17 @@
 
 #include "eckit/net/TCPStream.h"
 
-namespace eckit {
-namespace net {
+namespace eckit::net {
 
-
-
-TCPStream::TCPStream(net::TCPSocket& socket) : socket_(socket) {}
+TCPStream::TCPStream(net::TCPSocket& socket) :
+    socket_(socket) {}
 
 TCPStream::~TCPStream() {}
 
 void TCPStream::closeOutput() {
     socket_.closeOutput();
 }
-//======================
+//----------------------------------------------------------------------------------------------------------------------
 // Tricky solution to be removed when 'mutable' is available
 //
 std::string TCPStreamBase::nonConstName() {
@@ -35,10 +33,9 @@ std::string TCPStreamBase::name() const {
     return ((TCPStreamBase*)this)->nonConstName();
 }
 
-SharedTCPStream::SharedTCPStream(net::TCPSocket& s) : TCPStream(s) {}
+SharedTCPStream::SharedTCPStream(net::TCPSocket& s) :
+    TCPStream(s) {}
 
 SharedTCPStream::~SharedTCPStream() {}
 
-
-}  // namespace net
-}  // namespace eckit
+}  // namespace eckit::net
