@@ -26,22 +26,17 @@
 #include "eckit/net/UDPServer.h"
 #include "eckit/utils/Translator.h"
 
-namespace eckit {
-namespace net {
-
+namespace eckit::net {
 
 static void* get_sockaddr(struct sockaddr* sa) {
     if (sa->sa_family == AF_INET) {
         return &(((struct sockaddr_in*)sa)->sin_addr);
     }
-    else
-        return &(((struct sockaddr_in6*)sa)->sin6_addr);
+    return &(((struct sockaddr_in6*)sa)->sin6_addr);
 }
 
-
 UDPServer::UDPServer(int port) :
     port_(port), socketfd_(0) {
-
     struct addrinfo hints;
     struct addrinfo* servinfo;
     struct addrinfo* addr;
@@ -123,6 +118,4 @@ std::string UDPServer::remoteHost(struct sockaddr_storage& remote_addr) const {
     return r;
 }
 
-
-}  // namespace net
-}  // namespace eckit
+}  // namespace eckit::net
