@@ -14,14 +14,14 @@
 /// @date March 2016
 
 
+#include "eckit/option/CmdArgs.h"
+
 #include <iostream>
 #include <map>
 
 #include "eckit/exception/Exceptions.h"
-#include "eckit/option/CmdArgs.h"
 #include "eckit/option/Option.h"
 #include "eckit/runtime/Main.h"
-#include "eckit/utils/StringTools.h"
 #include "eckit/utils/Tokenizer.h"
 
 namespace eckit::option {
@@ -44,60 +44,85 @@ CmdArgs::CmdArgs(std::function<void(const std::string&)> usage, std::vector<Opti
     init(usage, args_count, minimum_args, throw_on_error);
 }
 
+namespace {
+
+std::vector<std::string> split_at(const std::string& s, char separator) {
+    if (auto found = s.find_first_of(separator); found != std::string::npos) {
+        return {s.substr(0, found), s.substr(found + 1)};
+    }
+    return {s};
+}
+
+}  // namespace
+
 void CmdArgs::init(std::function<void(const std::string&)> usage, int args_count, int minimum_args,
                    bool throw_on_error) {
-    Main& ctx  = Main::instance();
-    tool_      = ctx.name();
-    int argc   = ctx.argc();
-    bool error = false;
+    const Main& ctx = Main::instance();
+    tool_           = ctx.name();
+    int argc        = ctx.argc();
+    bool error      = false;
 
-    std::map<std::string, const option::Option*> opts;
+    using options_map_t = std::map<std::string, const option::Option*>;
 
-    for (std::vector<option::Option*>::const_iterator j = options_.begin(); j != options_.end(); ++j) {
-        if ((*j)->active()) {
-            ASSERT(opts.find((*j)->name()) == opts.end());
-            opts[(*j)->name()] = *j;
-            keys_.insert((*j)->name());
-            (*j)->setDefault(*this);
+    options_map_t opts;
+
+    // Fill in 'keys_' and prepare options map
+    for (Option* j : options_) {
+        if (j->active()) {
+            ASSERT(opts.find(j->name()) == opts.end());
+            keys_.insert(j->name());
+            opts[j->name()] = j;
+            j->setDefault(*this);
         }
     }
 
-    Tokenizer parse("=");
+    const static std::string prefix = "--";
+    // Process all options/values in argv, letting each Option collect the necessary entries
     for (int i = 1; i < argc; ++i) {
         std::string a = ctx.argv(i);
-        if (a.size() > 2 && a[0] == '-' && a[1] == '-') {
-            std::vector<std::string> v;
-            parse(a.substr(2), v);
+        if (a.substr(0, prefix.size()) == prefix) {  // An Option 'a' is found (starts with '--')!
 
-            std::map<std::string, const option::Option*>::const_iterator j = opts.find(v[0]);
-            if (j != opts.end()) {
+            // The Option might be formatted as --<name>=<value>
+            // ... so we remove the '--' prefix
+            a = a.substr(2);
+            // ... and tokenize [<name>(,<tail>)]
+            std::vector<std::string> tokens = Tokenizer::split_at(a, '=');
+
+            const std::string name = tokens[0];
+            tokens.erase(tokens.begin());
+
+            if (auto found = opts.find(name); found != opts.end()) {
                 try {
-                    if (v.size() == 1) {
-                        (*j).second->set(*this);
+                    const Option* option = found->second;
+                    // Given the applicable Option, we prepare the argv tokens (including the <value>)
+                    std::vector<std::string> remaining;
+                    remaining.reserve(tokens.size() + argc);
+                    for (const auto& token : tokens) {
+                        remaining.push_back(token);
                     }
-                    else {
-                        std::vector<std::string>::const_iterator b = v.begin();
-                        ++b;
-                        std::vector<std::string>::const_iterator e = v.end();
-                        (*j).second->set(StringTools::join("=", b, e), *this);
+                    for (int j = i + 1; j < argc; ++j) {
+                        remaining.push_back(ctx.argv(j));
                     }
+                    // ... allow the Option to set itself based on all remaining argv tokens
+                    size_t consumed = option->set(*this, tokens.size(), std::begin(remaining), std::end(remaining));
+                    // ... and, disregard the number of consumed tokens.
+                    i += static_cast<int>(consumed - tokens.size());
                 }
                 catch (UserError&) {
-                    Log::info() << "Invalid value for option --" << v[0] << std::endl;
+                    Log::info() << "Invalid value for option --" << name << std::endl;
                     error = true;
                 }
             }
             else {
-                Log::info() << "Invalid option --" << v[0] << std::endl;
+                Log::info() << "Invalid option --" << name << std::endl;
                 error = true;
             }
         }
-        else {
+        else { // Position argument 'a' is found!
             args_.push_back(a);
         }
     }
 
-
     if (args_count >= 0) {
         if (args_.size() != size_t(args_count)) {
             Log::info() << tool_ << ": invalid argument count: expected " << args_count << ", got: " << args_.size()
@@ -119,18 +144,16 @@ void CmdArgs::init(std::function<void(const std::string&)> usage, int args_count
         if (options_.size()) {
             Log::info() << std::endl;
             Log::info() << "Options are:" << std::endl;
-            Log::info() << "===========:" << std::endl
-                        << std::endl;
-            for (std::vector<option::Option*>::const_iterator j = options_.begin(); j != options_.end(); ++j) {
-                Log::info() << *(*j) << std::endl
-                            << std::endl;
+            Log::info() << "===========:" << std::endl << std::endl;
+            for (const Option* j : options_) {
+                Log::info() << *j << std::endl << std::endl;
             }
             Log::info() << std::endl;
         }
 
         if (throw_on_error) {
-            for (std::vector<option::Option*>::iterator j = options_.begin(); j != options_.end(); ++j) {
-                delete (*j);
+            for (const Option* j : options_) {
+                delete j;
             }
             throw UserError("An error occurred in argument parsing", Here());
         }
@@ -140,15 +163,15 @@ void CmdArgs::init(std::function<void(const std::string&)> usage, int args_count
 
 
 CmdArgs::~CmdArgs() {
-    for (std::vector<option::Option*>::iterator j = options_.begin(); j != options_.end(); ++j) {
-        delete (*j);
+    for (const Option* j : options_) {
+        delete j;
     }
 }
 
 
 void CmdArgs::configure(Configured& c) const {
-    for (std::vector<option::Option*>::const_iterator j = options_.begin(); j != options_.end(); ++j) {
-        (*j)->copy(*this, c);
+    for (const Option* j : options_) {
+        j->copy(*this, c);
     }
 }
 
@@ -159,14 +182,6 @@ void CmdArgs::print(std::ostream& out) const {
     out << "]";
 }
 
-// const std::set<std::string>& CmdArgs::keys() const {
-//     return keys_;
-// }
-
-// const std::vector<std::string>& CmdArgs::args() const {
-//     return args_;
-// }
-
 const std::string& CmdArgs::operator()(size_t i) const {
     ASSERT(i < args_.size());
     return args_[i];
@@ -179,6 +194,7 @@ size_t CmdArgs::count() const {
 const std::string& CmdArgs::tool() const {
     return tool_;
 }
+
 //----------------------------------------------------------------------------------------------------------------------
 
 }  // namespace eckit::option
