@@ -22,24 +22,21 @@ namespace eckit {
 
 class Library : public Main {
 
-public: // methods
-
+public:  // methods
     /// Contructors
 
-    Library(int argc, char **argv, const char* homeenv = nullptr);
+    Library(int argc, char** argv, const char* homeenv = nullptr);
 
     /// Destructor
 
-	virtual ~Library();
+    ~Library() override;
 
 protected:
-
     virtual Channel* createChannel() const;
-
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-} // namespace eckit
+}  // namespace eckit
 
 #endif
