@@ -17,9 +17,7 @@
 
 #include "eckit/sql/expression/SQLExpression.h"
 
-namespace eckit {
-namespace sql {
-namespace expression {
+namespace eckit::sql::expression {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -41,19 +39,17 @@ private:
     double value_;
     int which_;
 
-    virtual void print(std::ostream& s) const override;
-    virtual void prepare(SQLSelect& sql) override;
-    virtual void cleanup(SQLSelect& sql) override;
+    void print(std::ostream& s) const override;
+    void prepare(SQLSelect& sql) override;
+    void cleanup(SQLSelect& sql) override;
 
-    virtual double eval(bool& missing) const override;
-    virtual const type::SQLType* type() const override;
-    virtual bool isConstant() const override;
+    double eval(bool& missing) const override;
+    const type::SQLType* type() const override;
+    bool isConstant() const override;
 };
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace expression
-}  // namespace sql
-}  // namespace eckit
+}  // namespace eckit::sql::expression
 
 #endif
