@@ -18,9 +18,7 @@
 
 using namespace eckit;
 
-namespace eckit {
-namespace sql {
-namespace expression {
+namespace eckit::sql::expression {
 
 double const MISSING_VALUE_REAL = -2147483647.0;
 // long const MISSING_VALUE_INT =  2147483647;
@@ -74,8 +72,9 @@ void SQLExpression::title(const std::string& t) {
 }
 
 std::string SQLExpression::title() const {
-    if (title_.size())
+    if (title_.size()) {
         return title_;
+    }
 
     std::ostringstream s;
     s << *this;
@@ -92,6 +91,4 @@ void SQLExpression::expandStars(const std::vector<std::reference_wrapper<const S
     e.push_back(shared_from_this());
 }
 
-}  // namespace expression
-}  // namespace sql
-}  // namespace eckit
+}  // namespace eckit::sql::expression
