@@ -16,10 +16,7 @@
 
 #include "eckit/sql/expression/function/FunctionExpression.h"
 
-namespace eckit {
-namespace sql {
-namespace expression {
-namespace function {
+namespace eckit::sql::expression::function {
 
 class FunctionCOUNT : public FunctionExpression {
 public:
@@ -39,11 +36,11 @@ private:
     unsigned long long count_;
 
     // -- Overridden methods
-    virtual const eckit::sql::type::SQLType* type() const override;
-    virtual void prepare(SQLSelect&) override;
-    virtual void cleanup(SQLSelect&) override;
-    virtual void partialResult() override;
-    virtual double eval(bool& missing) const override;
+    const eckit::sql::type::SQLType* type() const override;
+    void prepare(SQLSelect&) override;
+    void cleanup(SQLSelect&) override;
+    void partialResult() override;
+    double eval(bool& missing) const override;
 
     bool isAggregate() const override { return true; }
 
@@ -52,9 +49,6 @@ private:
     //	{ p.print(s); return s; }
 };
 
-}  // namespace function
-}  // namespace expression
-}  // namespace sql
-}  // namespace eckit
+}  // namespace eckit::sql::expression::function
 
 #endif
