@@ -16,10 +16,7 @@
 
 #include "eckit/sql/expression/function/FunctionExpression.h"
 
-namespace eckit {
-namespace sql {
-namespace expression {
-namespace function {
+namespace eckit::sql::expression::function {
 
 class FunctionMIN : public FunctionExpression {
 public:
@@ -38,23 +35,20 @@ private:
     double value_;
 
     // -- Overridden methods
-    virtual const eckit::sql::type::SQLType* type() const override;
-    virtual void prepare(SQLSelect&) override;
-    virtual void cleanup(SQLSelect&) override;
-    virtual void partialResult() override;
-    virtual double eval(bool& missing) const override;
+    const eckit::sql::type::SQLType* type() const override;
+    void prepare(SQLSelect&) override;
+    void cleanup(SQLSelect&) override;
+    void partialResult() override;
+    double eval(bool& missing) const override;
     bool isAggregate() const override { return true; }
 
-    virtual void output(SQLOutput&) const override;
+    void output(SQLOutput&) const override;
 
     // -- Friends
     // friend std::ostream& operator<<(std::ostream& s,const FunctionMIN& p)
     //	{ p.print(s); return s; }
 };
 
-}  // namespace function
-}  // namespace expression
-}  // namespace sql
-}  // namespace eckit
+}  // namespace eckit::sql::expression::function
 
 #endif
