@@ -16,8 +16,7 @@
 
 #include "eckit/sql/type/SQLType.h"
 
-namespace eckit {
-namespace sql {
+namespace eckit::sql {
 
 class SQLOutput;
 
@@ -29,16 +28,16 @@ public:
     ~SQLDouble();
 
     // -- Overridden methods
-    virtual void output(SQLOutput&, double, bool) const override;
+    void output(SQLOutput&, double, bool) const override;
 
 private:
     // No copy allowed
     SQLDouble(const SQLDouble&);
     SQLDouble& operator=(const SQLDouble&);
 
-    virtual size_t size() const override;
-    virtual int getKind() const override { return doubleType; }
-    virtual std::string asString(const double* val) const override;
+    size_t size() const override;
+    int getKind() const override { return doubleType; }
+    std::string asString(const double* val) const override;
 
     // -- Friends
     // friend std::ostream& operator<<(std::ostream& s,const SQLDouble& p)
@@ -46,7 +45,6 @@ private:
 };
 
 }  // namespace type
-}  // namespace sql
-}  // namespace eckit
+}  // namespace eckit::sql
 
 #endif
