@@ -40,8 +40,7 @@
 #include "eckit/utils/Tokenizer.h"
 #include "eckit/utils/Translator.h"
 
-namespace eckit {
-namespace system {
+namespace eckit::system {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -155,16 +154,30 @@ public:  // methods
         return *(j->second);
     }
 
-    void* loadDynamicLibrary(const std::string& libname) {
+    const std::vector<std::string>& pluginSearchPaths() {
+        return plugin_search_paths_;
+    }
 
-        static std::vector<std::string> libPaths(Resource<std::vector<std::string>>(
+    std::vector<std::string> dynamicLibraryPaths() {
+        std::vector<std::string> libPaths(Resource<std::vector<std::string>>(
             "dynamicLibraryPath;$DYNAMIC_LIBRARY_PATH", {"~/lib64", "~/lib", "~eckit/lib64", "~eckit/lib"}));
 
+        for( auto& p: pluginSearchPaths() ) {
+            libPaths.push_back(p+"/lib");
+            libPaths.push_back(p+"/lib64");
+        }
+        return libPaths;
+    }
+
+    void* loadDynamicLibrary(const std::string& libname) {
+
         // Get the (system specific) library name for the given library instance
         std::string dynamicLibraryName = SystemInfo::instance().dynamicLibraryName(libname);
 
+        static std::vector<std::string> paths = dynamicLibraryPaths();
+
         // Try the various paths in the way
-        for (const std::string& dir : libPaths) {
+        for (const std::string& dir : paths) {
 
             LocalPathName path = dir + "/" + dynamicLibraryName;
 
@@ -206,9 +219,7 @@ public:  // methods
             std::string libname = it->second;
             return dynamic_cast<Plugin*>(&lookup(libname));
         }
-        else {
-            return nullptr;
-        }
+        return nullptr;
     }
 
     Plugin& loadPlugin(const std::string& name, const std::string& libname = std::string()) {
@@ -231,13 +242,12 @@ public:  // methods
                 initPlugin(plugin);
                 return *plugin;
             }
-            else {
-                // If the plugin library still doesn't exist after a successful call of dlopen, then
-                // we have managed to load something other than a (self-registering) eckit Plugin library
-                std::ostringstream ss;
-                ss << "Plugin library " << lib << " loaded but Plugin object " << name << " not registered";
-                throw UnexpectedState(ss.str(), Here());
-            }
+            // If the plugin library still doesn't exist after a successful call of dlopen, then
+            // we have managed to load something other than a (self-registering) eckit Plugin library
+            std::ostringstream ss;
+            ss << "Plugin library " << lib << " loaded but Plugin object " << name
+               << " not registered";
+            throw UnexpectedState(ss.str(), Here());
         }
 
         Plugin* plugin = lookupPlugin(name);
@@ -280,28 +290,38 @@ public:  // methods
         }
     }
 
-    std::map<std::string, LocalConfiguration> scanManifestPaths() {
-        std::map<std::string, LocalConfiguration> manifests;
+    std::vector<std::string> pluginManifestScanPaths() {
+        std::vector<std::string> scanPaths;
+        eckit::Tokenizer tokenize(":");
 
         static std::string pluginManifestPath = Resource<std::string>("$PLUGINS_MANIFEST_PATH;pluginManifestPath", "");
-
-        eckit::Tokenizer tokenize(":");
-        std::vector<std::string> scanPaths;
         tokenize(pluginManifestPath, scanPaths);
 
+        for( const auto& p: pluginSearchPaths()) {
+            scanPaths.push_back(p+"/share/plugins");
+        }
+
         // always scan ~eckit/share/plugins and ~/share/plugins as a last resort
         scanPaths.push_back("~eckit/share/plugins");
         scanPaths.push_back("~/share/plugins");
 
+        return scanPaths;
+    }
+
+    std::map<std::string, LocalConfiguration> scanManifestPaths() {
+        std::map<std::string, LocalConfiguration> manifests;
+        std::vector<std::string> scanPaths = pluginManifestScanPaths();
+
         Log::debug() << "Plugins manifest candidate paths " << scanPaths << std::endl;
 
         std::set<LocalPathName> visited;  //< we dont visit same path twice
 
-        for (auto& path : scanPaths) {
+        for (const auto& path : scanPaths) {
 
             LocalPathName dir(path);
-            if (not dir.exists() or not dir.isDir())
+            if (not dir.exists() or not dir.isDir()) {
                 continue;
+            }
 
             LocalPathName realdir(dir.realName());
             if (visited.count(realdir)) {
@@ -393,7 +413,13 @@ public:  // methods
         is_plugin_initialized_.erase(name);
     }
 
+    void addPluginSearchPath(const std::string& path) {
+        Tokenizer tokenizer(":");
+        tokenizer(path, plugin_search_paths_);
+    }
+
 private:  // members
+    std::vector<std::string> plugin_search_paths_;
     LibraryMap libs_;
     std::map<std::string, std::string> plugins_;  //< map plugin name to library
     std::map<std::string, bool> is_plugin_initialized_;
@@ -427,9 +453,10 @@ const Library& LibraryManager::lookup(const std::string& name) {
 }
 
 const Plugin& LibraryManager::lookupPlugin(const std::string& name) {
-    Plugin * plugin = LibraryRegistry::instance().lookupPlugin(name);
-    if(plugin)
+    Plugin* plugin = LibraryRegistry::instance().lookupPlugin(name);
+    if (plugin) {
         return *plugin;
+    }
     throw eckit::BadValue("Plugin " + name + " not loaded");
 }
 
@@ -453,7 +480,10 @@ void LibraryManager::deregisterPlugin(const std::string& name) {
     LibraryRegistry::instance().deregisterPlugin(name);
 }
 
+void LibraryManager::addPluginSearchPath(const std::string& path) {
+    LibraryRegistry::instance().addPluginSearchPath(path);
+}
+
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace system
-}  // namespace eckit
+}  // namespace eckit::system
