@@ -15,13 +15,13 @@
 #ifndef eckit_testing_Test_h
 #define eckit_testing_Test_h
 
-#include <cstdlib> // for setenv
+#include <cstdlib>  // for setenv
 
 #include <functional>
+#include <set>
 #include <sstream>
 #include <string>
 #include <vector>
-#include <set>
 
 #include "eckit/exception/Exceptions.h"
 #include "eckit/log/Colour.h"
@@ -30,15 +30,14 @@
 #include "eckit/types/FloatCompare.h"
 #include "eckit/utils/Translator.h"
 
-
-namespace eckit {
-namespace testing {
+namespace eckit::testing {
 
 //----------------------------------------------------------------------------------------------------------------------
 
 class TestException : public Exception {
 public:
-    TestException(const std::string& w, const CodeLocation& l) : Exception(w, l) {}
+    TestException(const std::string& w, const CodeLocation& l) :
+        Exception(w, l) {}
 };
 
 enum TestVerbosity
@@ -57,7 +56,8 @@ enum InitEckitMain
 
 class SetEnv {
 public:
-    SetEnv(const char* key, const char* val) : key_(key), value_(val) {
+    SetEnv(const char* key, const char* val) :
+        key_(key), value_(val) {
         oldValue_ = ::getenv(key_);
         ::setenv(key_, value_, true);
     }
@@ -152,9 +152,7 @@ public:  // methods
         if (subsection_.length() != 0) {
             return description_ + " (section: " + subsection_ + ")";
         }
-        else {
-            return description_;
-        }
+        return description_;
     }
 
     const std::string& descriptionNoSection() const {
@@ -193,9 +191,12 @@ template <typename T>
 class ArrayView {
 public:
     // -- Constructors
-    ArrayView(const T* data, size_t size) : data_(data), size_(size) {}
-    ArrayView(const T* begin, const T* end) : data_(begin), size_(end - begin) {}
-    explicit ArrayView(const std::vector<T>& vec) : data_(&vec[0]), size_(vec.size()) {}
+    ArrayView(const T* data, size_t size) :
+        data_(data), size_(size) {}
+    ArrayView(const T* begin, const T* end) :
+        data_(begin), size_(end - begin) {}
+    explicit ArrayView(const std::vector<T>& vec) :
+        data_(&vec[0]), size_(vec.size()) {}
 
     // -- Accessors
     const T& operator[](int i) const { return data_[i]; }
@@ -237,25 +238,32 @@ private:
     // -- Private Methods
     template <typename U>
     bool compareEqual_(const U* data, const size_t size) const {
-        if (size != this->size())
+        if (size != this->size()) {
             return false;
-        if (size == 0)
+        }
+        if (size == 0) {
             return true;
-        for (size_t i = 0; i < this->size(); i++)
-            if (data[i] != this->at(i))
+        }
+        for (size_t i = 0; i < this->size(); i++) {
+            if (data[i] != this->at(i)) {
                 return false;
+            }
+        }
         return true;
     }
 
     template <typename U>
     bool compareApproxEqual_(const U* data, const size_t size, const U epsilon) const {
-        if (size != this->size())
+        if (size != this->size()) {
             return false;
-        if (size == 0)
+        }
+        if (size == 0) {
             return true;
+        }
         for (size_t i = 0; i < this->size(); i++) {
-            if (!eckit::types::is_approximately_equal(this->at(i), data[i], epsilon))
+            if (!eckit::types::is_approximately_equal(this->at(i), data[i], epsilon)) {
                 return false;
+            }
         }
         return true;
     }
@@ -319,8 +327,9 @@ inline int run(std::vector<Test>& tests, TestVerbosity v = AllFailures) {
     size_t num_tests = tests.size();
 
     if (num_tests == 0) {
-        if (v >= Summary)
+        if (v >= Summary) {
             eckit::Log::info() << "Eckit testing found no test cases to run." << std::endl;
+        }
         return -1;
     }
 
@@ -364,7 +373,8 @@ inline int run(std::vector<Test>& tests, TestVerbosity v = AllFailures) {
             eckit::Log::info() << "Running case " << i << ": " << test.description() << " ..." << std::endl;
             test.run(v, failures);
             eckit::Log::info() << "Completed case " << i << ": " << test.descriptionNoSection() << std::endl;
-        } else {
+        }
+        else {
             eckit::Log::info() << "Skipping case " << i << ": " << test.description() << "..." << std::endl;
         }
     }
@@ -379,16 +389,17 @@ inline int run(std::vector<Test>& tests, TestVerbosity v = AllFailures) {
 }
 
 int run_tests_main(std::vector<Test>& tests, int argc, char* argv[], bool initEckitMain = true) {
-    
+
     // deactivate loading of plugins not to influence some tests
     ::setenv("AUTO_LOAD_PLUGINS", "false", true);
-    
-    if (initEckitMain)
+
+    if (initEckitMain) {
         eckit::Main::initialise(argc, argv);
-    
+    }
+
     eckit::Log::info() << "Running " << tests.size() << " tests:" << std::endl;
     int failures = run(tests);
-    
+
     eckit::Log::info() << failures << " tests failed out of " << tests.size() << "." << std::endl;
     return failures;
 }
@@ -403,8 +414,7 @@ int run_tests(int argc, char* argv[], bool initEckitMain = true) {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace testing
-}  // namespace eckit
+}  // namespace eckit::testing
 
 // Helper macros for unique naming
 
@@ -417,10 +427,10 @@ int run_tests(int argc, char* argv[], bool initEckitMain = true) {
 
 #if ECKIT_TESTING_SELF_REGISTER_CASES
 
-#define CASE(description)                                                                                           \
-    void UNIQUE_NAME2(test_, __LINE__)(std::string&, int&, int);                                                    \
+#define CASE(description)                                                                                                 \
+    void UNIQUE_NAME2(test_, __LINE__)(std::string&, int&, int);                                                          \
     static const eckit::testing::TestRegister UNIQUE_NAME2(test_registration_, __LINE__)(description,                     \
-                                                                                   &UNIQUE_NAME2(test_, __LINE__)); \
+                                                                                         &UNIQUE_NAME2(test_, __LINE__)); \
     void UNIQUE_NAME2(test_, __LINE__)(std::string & _test_subsection, int& _num_subsections, int _subsection)
 
 #else  // ECKIT_TESTING_SELF_REGISTER_CASES
