@@ -33,7 +33,7 @@ public:
 
     // -- Destructor
 
-    virtual ~TxnEvent() override;
+    ~TxnEvent() override;
 
     // -- Methods
 
@@ -44,8 +44,8 @@ public:
 
     // From Streamble
 
-    virtual void encode(Stream&) const override;
-    virtual const ReanimatorBase& reanimator() const override { return reanimator_; }
+    void encode(Stream&) const override;
+    const ReanimatorBase& reanimator() const override { return reanimator_; }
 
 
     // -- Class members
