@@ -16,7 +16,6 @@
 namespace eckit {
 
 class Buffer;
-class ResizableBuffer;
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -25,10 +24,10 @@ class LZ4Compressor : public eckit::Compressor {
 public:  // methods
     LZ4Compressor();
 
-    virtual ~LZ4Compressor() override;
+    ~LZ4Compressor() override;
 
-    virtual size_t compress(const eckit::Buffer& in, eckit::ResizableBuffer& out) const;
-    virtual size_t uncompress(const eckit::Buffer& in, eckit::ResizableBuffer& out) const;
+    size_t compress(const void* in, size_t len, eckit::Buffer& out) const override;
+    void uncompress(const void* in, size_t len, eckit::Buffer& out, size_t outlen) const override;
 
 protected:  // methods
 };
