@@ -37,15 +37,15 @@ public:  // types
 
     MD4(const void* data, size_t len);
 
-    virtual ~MD4() override;
+    ~MD4() override;
 
-    virtual void reset() const override;
+    void reset() const override;
 
-    virtual digest_t compute(const void*, long) override;
+    digest_t compute(const void*, long) override;
 
-    virtual void update(const void*, long) override;
+    void update(const void*, long) override;
 
-    virtual digest_t digest() const override;
+    digest_t digest() const override;
 
     template <class T>
     MD4& operator<<(const T& x) {
