@@ -31,8 +31,7 @@ using namespace std;
 using namespace eckit;
 using namespace eckit::testing;
 
-namespace eckit {
-namespace test {
+namespace eckit::test {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -40,10 +39,12 @@ int get_pagesize() {
     int pagesize;
     errno = 0ll;
     if ((pagesize = sysconf(_SC_PAGE_SIZE)) == -1) {
-        if (errno == 0)
+        if (errno == 0) {
             printf("PAGE_SIZE not supported by sysconf implementation\n");
-        else
+        }
+        else {
             perror("sysconf error.");
+        }
 
         exit(EXIT_FAILURE);
     }
@@ -84,50 +85,58 @@ CASE("Test memory map") {
     // make temporary file name
     int fd;
     char filename[] = "mmaped.XXXXXX";
-    if ((fd = ::mkstemp(filename)) == -1)
+    if ((fd = ::mkstemp(filename)) == -1) {
         perror("cannot create temporary file"), exit(EXIT_FAILURE);
+    }
 
     // file is opened in mkstemp, so this is not needed
     //    if( ( fd = ::open(filename, O_RDWR | O_CREAT | O_TRUNC, (mode_t)0600) ) == -1 )
     //      perror("Error opening file"),  exit(EXIT_FAILURE);
 
     // stretch the file size to the size of the (mmapped) array of ints
-    if ((long long)::lseek(fd, TOTAL_SIZE - 1, SEEK_SET) < 0)
+    if ((long long)::lseek(fd, TOTAL_SIZE - 1, SEEK_SET) < 0) {
         perror("Error calling lseek() to 'stretch' the file"), exit(EXIT_FAILURE);
+    }
 
     // write something to the end of the file to actually resize it correctly
-    if (::write(fd, "", 1) != 1)
+    if (::write(fd, "", 1) != 1) {
         close(fd), perror("Error writing last byte of the file"), exit(EXIT_FAILURE);
+    }
 
     // map the file
     std::cout << "mapping " << Bytes(MAP_SIZE) << " from " << Bytes(SIZE_LW) << " to " << Bytes(SIZE_UP) << std::endl;
 
-    if ((map = (int*)MMap::mmap(0, MAP_SIZE, PROT_READ | PROT_WRITE, MAP_SHARED, fd, ELEM_LW)) == MAP_FAILED)
+    if ((map = (int*)MMap::mmap(0, MAP_SIZE, PROT_READ | PROT_WRITE, MAP_SHARED, fd, SIZE_LW))
+        == MAP_FAILED) {
         close(fd), perror("Error mmapping the file"), exit(EXIT_FAILURE);
+    }
 
     // write to file as if it were memory
-    for (int i = 0; i < NELEMS; ++i)
+    for (int i = 0; i < NELEMS; ++i) {
         map[i] = 2 * i;
+    }
 
     // free the mmapped memory
-    if (MMap::munmap(map, MAP_SIZE) == -1)
+    if (MMap::munmap(map, MAP_SIZE) == -1) {
         perror("Error un-mmapping the file"), exit(EXIT_FAILURE);
+    }
 
     // close the file
-    if (close(fd) == -1)
+    if (close(fd) == -1) {
         perror("Error closing file descriptot"), exit(EXIT_FAILURE);
+    }
 
     // test that the contents of the file are correct
 
     // remove the file -- its large!
-    if (::unlink(filename) == -1)
+    if (::unlink(filename) == -1) {
         perror("Error removing the file"), exit(EXIT_FAILURE);
+    }
 }
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace test
-}  // namespace eckit
+}  // namespace eckit::test
 
 int main(int argc, char** argv) {
     return run_tests(argc, argv);
