@@ -23,8 +23,7 @@ using namespace eckit;
 using namespace eckit::types;
 using namespace eckit::testing;
 
-namespace eckit {
-namespace test {
+namespace eckit::test {
 
 //----------------------------------------------------------------------------------------------------------------------
 
@@ -80,12 +79,12 @@ CASE("test_broadcast") {
 
     Log::info() << "Test vector<pair<int,int>>" << std::endl;
     {
-        std::vector< std::pair<int,int> > data(5);
+        std::vector<std::pair<int, int> > data(5);
         if (mpi::comm().rank() == root) {
-            size_t j=0;
-            for(size_t i=0; i<5; ++i) {
-                data[i].first=d[j++];
-                data[i].second=d[j++];
+            size_t j = 0;
+            for (size_t i = 0; i < 5; ++i) {
+                data[i].first  = d[j++];
+                data[i].second = d[j++];
             }
         }
 
@@ -94,8 +93,8 @@ CASE("test_broadcast") {
         // check results
         std::vector<int> unpacked(10);
         {
-            size_t j=0;
-            for(size_t i=0; i<5; ++i) {
+            size_t j = 0;
+            for (size_t i = 0; i < 5; ++i) {
                 unpacked[j++] = data[i].first;
                 unpacked[j++] = data[i].second;
             }
@@ -105,12 +104,12 @@ CASE("test_broadcast") {
 
     Log::info() << "Test vector<pair<long,long>>" << std::endl;
     {
-        std::vector< std::pair<long,long> > data(5);
+        std::vector<std::pair<long, long> > data(5);
         if (mpi::comm().rank() == root) {
-            size_t j=0;
-            for(size_t i=0; i<5; ++i) {
-                data[i].first=d[j++];
-                data[i].second=d[j++];
+            size_t j = 0;
+            for (size_t i = 0; i < 5; ++i) {
+                data[i].first  = d[j++];
+                data[i].second = d[j++];
             }
         }
 
@@ -119,8 +118,8 @@ CASE("test_broadcast") {
         // check results
         std::vector<int> unpacked(10);
         {
-            size_t j=0;
-            for(size_t i=0; i<5; ++i) {
+            size_t j = 0;
+            for (size_t i = 0; i < 5; ++i) {
                 unpacked[j++] = data[i].first;
                 unpacked[j++] = data[i].second;
             }
@@ -130,12 +129,12 @@ CASE("test_broadcast") {
 
     Log::info() << "Test vector<pair<long long,long long>>" << std::endl;
     {
-        std::vector< std::pair<long long,long long> > data(5);
+        std::vector<std::pair<long long, long long> > data(5);
         if (mpi::comm().rank() == root) {
-            size_t j=0;
-            for(size_t i=0; i<5; ++i) {
-                data[i].first=d[j++];
-                data[i].second=d[j++];
+            size_t j = 0;
+            for (size_t i = 0; i < 5; ++i) {
+                data[i].first  = d[j++];
+                data[i].second = d[j++];
             }
         }
 
@@ -144,15 +143,14 @@ CASE("test_broadcast") {
         // check results
         std::vector<int> unpacked(10);
         {
-            size_t j=0;
-            for(size_t i=0; i<5; ++i) {
+            size_t j = 0;
+            for (size_t i = 0; i < 5; ++i) {
                 unpacked[j++] = data[i].first;
                 unpacked[j++] = data[i].second;
             }
         }
         EXPECT(unpacked == expect);
     }
-
 }
 
 CASE("test_gather_scalar") {
@@ -355,23 +353,23 @@ CASE("test_scatterv") {
 CASE("sendReceiveReplace") {
     int mpi_rank = mpi::comm().rank();
     int mpi_size = mpi::comm().size();
-    int first = 0;
-    int last  = mpi_size - 1;
-    int sendtag = 0;
-    int recvtag = 0;
+    int first    = 0;
+    int last     = mpi_size - 1;
+    int sendtag  = 0;
+    int recvtag  = 0;
     Log::info() << "Testing swap" << std::endl;
     {
         int d = mpi_rank + 1;
         if (mpi_rank == first) {
-            int dest = last; // send to last
-            int src = last;  // receive from last
+            int dest = last;  // send to last
+            int src  = last;  // receive from last
             EXPECT_EQUAL(d, 1);
             EXPECT_NO_THROW(mpi::comm().sendReceiveReplace(d, dest, sendtag, src, recvtag));
             EXPECT_EQUAL(d, mpi_size);
         }
         if (mpi_rank == last) {
-            int dest = first; // send to first
-            int src = first;  // receive to first
+            int dest = first;  // send to first
+            int src  = first;  // receive to first
             EXPECT_EQUAL(d, mpi_size);
             EXPECT_NO_THROW(mpi::comm().sendReceiveReplace(d, dest, sendtag, src, recvtag));
             EXPECT_EQUAL(d, 1);
@@ -379,31 +377,31 @@ CASE("sendReceiveReplace") {
     }
     Log::info() << "Testing open end shift" << std::endl;
     {
-        int d = mpi_rank + 1;
-        int expected = d+1;
+        int d        = mpi_rank + 1;
+        int expected = d + 1;
         if (mpi_rank == last) {
             expected = d;
         }
-        int dest = mpi_rank-1; // send to lower rank
-        int src  = mpi_rank+1; // receive from higher rank
+        int dest = mpi_rank - 1;  // send to lower rank
+        int src  = mpi_rank + 1;  // receive from higher rank
         if (mpi_rank == first) {
-            dest = mpi::comm().procNull(); // first receives nothing
+            dest = mpi::comm().procNull();  // first receives nothing
         }
         if (mpi_rank == last) {
-            src = mpi::comm().procNull(); // last sends nothing
+            src = mpi::comm().procNull();  // last sends nothing
         }
         EXPECT_NO_THROW(mpi::comm().sendReceiveReplace(d, dest, sendtag, src, recvtag));
         EXPECT_EQUAL(d, expected);
     }
     Log::info() << "Testing circular shift" << std::endl;
     {
-        int d = mpi_rank + 1;
-        int expected = d+1;
+        int d        = mpi_rank + 1;
+        int expected = d + 1;
         if (mpi_rank == last) {
-            expected = first+1;
+            expected = first + 1;
         }
-        int dest = mpi_rank-1;  // send to lower rank
-        int src  = mpi_rank+1;
+        int dest = mpi_rank - 1;  // send to lower rank
+        int src  = mpi_rank + 1;
         if (mpi_rank == first) {
             dest = last;
         }
@@ -430,21 +428,21 @@ CASE("test_reduce") {
 
     // check results
     int root = 0; /* master */
-    int s = 0;
-    int p = 1;
-    int mx = 0;
-    int mn = mpi_size;
-    std::pair<double,int> mxloc{-double(mpi_size),mpi_size-1};
-    std::pair<double,int> mnloc{-double(1),0};
+    int s    = 0;
+    int p    = 1;
+    int mx   = 0;
+    int mn   = mpi_size;
+    std::pair<double, int> mxloc{-double(mpi_size), mpi_size - 1};
+    std::pair<double, int> mnloc{-double(1), 0};
     if (mpi_rank == root) {
         for (size_t j = 0; j < mpi_size; ++j) {
             s += (j + 1);
             p *= (j + 1);
         }
-        mx = mpi_size;
-        mn = 1;
-        mxloc = std::pair<double,int>{-double(1),0};
-        mnloc = std::pair<double,int>{-double(mpi_size),mpi_size-1};
+        mx    = mpi_size;
+        mn    = 1;
+        mxloc = std::pair<double, int>{-double(1), 0};
+        mnloc = std::pair<double, int>{-double(mpi_size), mpi_size - 1};
     }
 
     Log::info() << "Testing reduce" << std::endl;
@@ -465,16 +463,15 @@ CASE("test_reduce") {
         EXPECT_NO_THROW(mpi::comm().reduce(d, min, mpi::min(), root));
         EXPECT_EQUAL(min, mn);
 
-        std::pair<double, int> maxloc{-double(mpi_size),mpi_size-1};
+        std::pair<double, int> maxloc{-double(mpi_size), mpi_size - 1};
         EXPECT_NO_THROW(mpi::comm().reduce(v, maxloc, mpi::maxloc(), root));
-        EXPECT_EQUAL(maxloc.first, mxloc.first );
+        EXPECT_EQUAL(maxloc.first, mxloc.first);
         EXPECT_EQUAL(maxloc.second, mxloc.second);
 
-        std::pair<double, int> minloc{-double(1),0};
+        std::pair<double, int> minloc{-double(1), 0};
         EXPECT_NO_THROW(mpi::comm().reduce(v, minloc, mpi::minloc(), root));
-        EXPECT_EQUAL(minloc.first, mnloc.first );
+        EXPECT_EQUAL(minloc.first, mnloc.first);
         EXPECT_EQUAL(minloc.second, mnloc.second);
-
     }
 
     std::vector<float> arr(5, mpi_rank + 1);
@@ -493,8 +490,8 @@ CASE("test_reduce") {
         int min  = d;
 
         if (mpi_rank != root) {
-            s = d;
-            p = d;
+            s  = d;
+            p  = d;
             mx = d;
             mn = d;
         }
@@ -513,26 +510,25 @@ CASE("test_reduce") {
 
         std::vector<float> expected;
 
-        expected = (mpi_rank == root) ? std::vector<float>(5, mpi_size) : arr;
+        expected                  = (mpi_rank == root) ? std::vector<float>(5, mpi_size) : arr;
         std::vector<float> maxvec = arr;
         EXPECT_NO_THROW(mpi::comm().reduceInPlace(maxvec.begin(), maxvec.end(), mpi::max(), root));
         EXPECT_EQUAL(maxvec, expected);
 
-        expected = (mpi_rank == root) ? std::vector<float>(5, 1) : arr;
+        expected                  = (mpi_rank == root) ? std::vector<float>(5, 1) : arr;
         std::vector<float> minvec = arr;
         EXPECT_NO_THROW(mpi::comm().reduceInPlace(minvec.begin(), minvec.end(), mpi::min(), root));
         EXPECT_EQUAL(minvec, expected);
 
-        expected = (mpi_rank == root) ? std::vector<float>(5, s) : arr;
+        expected                  = (mpi_rank == root) ? std::vector<float>(5, s) : arr;
         std::vector<float> sumvec = arr;
         EXPECT_NO_THROW(mpi::comm().reduceInPlace(sumvec.begin(), sumvec.end(), mpi::sum(), root));
         EXPECT_EQUAL(sumvec, expected);
 
-        expected = (mpi_rank == root) ? std::vector<float>(5, p) : arr;
+        expected                   = (mpi_rank == root) ? std::vector<float>(5, p) : arr;
         std::vector<float> prodvec = arr;
         EXPECT_NO_THROW(mpi::comm().reduceInPlace(prodvec.begin(), prodvec.end(), mpi::prod(), root));
         EXPECT_EQUAL(prodvec, expected);
-
     }
 }
 
@@ -667,8 +663,9 @@ CASE("test_allGatherv") {
     // check results
     std::vector<int> expected;
     for (size_t j = 0; j < mpi::comm().size(); ++j) {
-        for (size_t i = 0; i < j; ++i)
+        for (size_t i = 0; i < j; ++i) {
             expected.push_back(j);
+        }
     }
 
     EXPECT(recv.buffer == expected);
@@ -1016,8 +1013,7 @@ CASE("test_iProbe") {
 
 //----------------------------------------------------------------------------------------------------------------------
 
-}  // namespace test
-}  // namespace eckit
+}  // namespace eckit::test
 
 int main(int argc, char** argv) {
     int failures = run_tests(argc, argv);
